referrerpolicy=no-referrer-when-downgrade

request_core_count

Function request_core_count 

pub fn request_core_count<T: Config>(count: u16)
Request the configuration to be updated with the specified number of cores. Warning: Since this only schedules a configuration update, it takes two sessions to come into effect.

  • origin: Root or the Coretime Chain
  • count: total number of cores

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::request_core_count.